==> fetch.php?media=snfit-2.2.2.tar.gz: snfit-2.2.2/src/poly1.h <==
#ifndef POLY1__H
#define POLY1__H

#include <string>

#include "matvect.h"

#include "fstream"



//! Regular 1D polynomial.
class Poly1
{
 protected :
  Vect params;
  unsigned npar;
  double a,b;

  /*
    a and b are chosen to map the x varying interval on [-1,1] (fit numerics)
    val(x) = sum_k params(k)*(a*x+b)**k
  */

 public:
  
  Poly1() {
    SetDeg(1);
    SetRange(0.,1.);
  }
  

 Poly1(const int Deg, const double& XMin, const double& XMax)
  {
    SetDeg(Deg);
    SetRange(XMin,XMax);
  };
 virtual ~Poly1() {}


  Poly1(const std::string &FileName) { npar = 0; a=b=0; Read(FileName);}

  void SetRange(const double& XMin, const double& XMax) {
    a = (XMax-XMin)? 2./(XMax-XMin) : 1;
    b = 1-a*XMax;
  }
  void SetDeg(int deg) {
    npar = (deg+1);
    params.allocate(npar);
  }

  void ParamDerivatives(const double &X, Vect &H) const
  {
    double xred = a*X+b;
    double p = 1;
    for (unsigned k=0; k <npar; ++k)
      {
	H(k) = p;
	p*= xred;
      }
  }

  double Value(const double &X) const
  {
    double val = 0;
    Vect der(npar);
    ParamDerivatives(X,der);
    for (unsigned k=0; k <npar; ++k) val += der(k)*params(k);
    return val;
  }

  virtual unsigned NPar() const { return npar;};

  virtual void SetParams(const Vect &P)
  {
    for (unsigned k =0; k < npar; ++k) params(k) = P(k);
  }
  virtual void SetParam(size_t i,const double &val)
  {
    params(i) = val;
  }
  
  void Write(std::ostream &file) const;
  void Write(const std::string &FileName) const;

  virtual const Vect Params() const { return params;}
  virtual double Param(size_t i) const { return params(i);}
  
  void operator += (const Poly1 &Right);

  bool Read(const std::string &FileName);

  bool Read(std::istream &file);




};




#endif /* POLY1__H */

==> fetch.php?media=snfit-2.4.1.tar.gz: snfit-2.4.2/src/poly1.h <==
#ifndef POLY1__H
#define POLY1__H

#include <string>

#include "matvect.h"

#include "fstream"



//! Regular 1D polynomial.
class Poly1
{
 protected :
  Vect params;
  size_t npar;
  double a,b;

  /*
    a and b are chosen to map the x varying interval on [-1,1] (fit numerics)
    val(x) = sum_k params(k)*(a*x+b)**k
  */

 public:
  
  Poly1() {
    SetDeg(1);
    SetRange(0.,1.);
  }
  

 Poly1(const int Deg, const double& XMin, const double& XMax)
  {
    SetDeg(Deg);
    SetRange(XMin,XMax);
  };
 virtual ~Poly1() {}


  Poly1(const std::string &FileName) { npar = 0; a=b=0; Read(FileName);}

  void SetRange(const double& XMin, const double& XMax) {
    a = (XMax-XMin)? 2./(XMax-XMin) : 1;
    b = 1-a*XMax;
  }
  void SetDeg(int deg) {
    npar = (deg+1);
    params.allocate(npar);
  }

  void ParamDerivatives(const double &X, Vect &H) const
  {
    double xred = a*X+b;
    double p = 1;
    for (size_t k=0; k <npar; ++k)
      {
	H(k) = p;
	p*= xred;
      }
  }

  double Value(const double &X) const
  {
    double val = 0;
    Vect der(npar);
    ParamDerivatives(X,der);
    for (size_t k=0; k <npar; ++k) val += der(k)*params(k);
    return val;
  }

  virtual size_t NPar() const { return npar;};

  virtual void SetParams(const Vect &P)
  {
    for (size_t k =0; k < npar; ++k) params(k) = P(k);
  }
  virtual void SetParam(size_t i,const double &val)
  {
    params(i) = val;
  }
  
  void Write(std::ostream &file) const;
  void Write(const std::string &FileName) const;

  virtual const Vect Params() const { return params;}
  virtual double Param(size_t i) const { return params(i);}
  
  void operator += (const Poly1 &Right);

  bool Read(const std::string &FileName);

  bool Read(std::istream &file);




};




#endif /* POLY1__H */
